@@ -1,5 +1,5 @@
 """
-Modulo que contiene la clase la cual representa el metodo de busqueda de LocalSearch
+Modulo que contiene la clase la cual representa el metodo de búsqueda de LocalSearch
 
 """
 
@@ -11,7 +11,7 @@ class LocalSearch():
     
     
     def __init__(self, options: AlgorithmsOptions = None, problem: Tsp = None) -> None:
-        """ Clase Local Search la cual representa este metodo de busqueda
+        """ Clase Local Search la cual representa este metodo de búsqueda
 
         Parameters
         ----------
@@ -31,7 +31,7 @@ class LocalSearch():
         total_time : float
             Tiempo de ejecucion de Local Search
         trajectory : list
-            Lista de objetos de la trayectoria de la solucion
+            Lista de objetos de la trayectoria de la solución
         bestImprovement : bool
             Si es de tipo best improvement o no
 
@@ -55,7 +55,7 @@ class LocalSearch():
 
         self.options: AlgorithmsOptions # Opciones
 
-        self.trajectory = [] # lista con la trayectoria de la solucion
+        self.trajectory = [] # lista con la trayectoria de la solución
         
         self.bestImprovement = False # si es best improvement
         
@@ -78,30 +78,30 @@ class LocalSearch():
         
         
     def print_best_solution(self) -> None:
-        """ Escribir la mejor solucion """
+        """ Escribir la mejor solución """
         self.updateLog()
         print()
-        print(f"\t\t{bcolors.UNDERLINE}Mejor Solucion Encontrada{bcolors.ENDC}\n")
+        print(f"\t\t{bcolors.UNDERLINE}Mejor Solución Encontrada{bcolors.ENDC}\n")
         self.best_tour.printSol(True)
         print(f"{bcolors.BOLD}Total de evaluaciones:{bcolors.ENDC} {bcolors.OKBLUE}{self.evaluations-1}{bcolors.ENDC}")
-        print(f"{bcolors.BOLD}Tiempo total de busqueda con Local Search:{bcolors.ENDC} {bcolors.OKBLUE}{self.total_time:.3f} segundos{bcolors.ENDC}")
+        print(f"{bcolors.BOLD}Tiempo total de búsqueda con Local Search:{bcolors.ENDC} {bcolors.OKBLUE}{self.total_time:.3f} segundos{bcolors.ENDC}")
 
     
     def search(self, first_solution: Tour = None) -> None:
-        """ Ejecuta la busqueda de Local Search desde una solucion inicial """
+        """ Ejecuta la búsqueda de Local Search desde una solución inicial """
 
         table = PrettyTable()
 
         table.field_names = [f"{bcolors.BOLD}Evaluaciones", "Tiempo", f"Detalles{bcolors.ENDC}"]
 
-        # Si el atributo opcional de la solucion inicial no esta incluido
+        # Si el atributo opcional de la solución inicial no esta incluido
         if not first_solution:
             first_solution = Tour(type_initial_sol=self.options.initial_solution, problem=self.problem)
 
  
         current_tour = Tour(tour=first_solution) # variable del tour actual
         
-        self.best_tour.copy(first_solution) # solucion inicial se guarda como la mejor hasta el momento
+        self.best_tour.copy(first_solution) # solución inicial se guarda como la mejor hasta el momento
         # Guardar trayectoria Inicial
         self.trajectory.append( Trajectory(
                                 tour=self.best_tour.current.copy(),
@@ -115,7 +115,7 @@ class LocalSearch():
                                     iterations=self.evaluations-1, 
                                     evaluations=self.evaluations-1) )
                                 
-        print(f"{bcolors.UNDERLINE}\nComenzando busqueda, solucion inicial: {bcolors.ENDC}")
+        print(f"{bcolors.UNDERLINE}\nComenzando búsqueda, solución inicial: {bcolors.ENDC}")
         self.best_tour.printSol()
 
        
@@ -123,7 +123,7 @@ class LocalSearch():
             print(f"{bcolors.HEADER}\nEjecutando Local Search...\n{bcolors.ENDC}")
             
             
-        # Ejecucion de la busqueda segun el metodo
+        # Ejecucion de la búsqueda segun el metodo
         if self.move_type == TSPMove.SWAP:
             self.swapSearch(current_tour, table)
         elif self.move_type == TSPMove.TWO_OPT:
@@ -155,7 +155,7 @@ class LocalSearch():
     """
             
     def swapSearch(self, tour: Tour, table: PrettyTable = PrettyTable()) -> None:
-        """ Aplica la busqueda por 3-opt """
+        """ Aplica la búsqueda por 3-opt """
         #print(tour.current)   
         n = self.problem.getSize()
         if n < 3: 
@@ -184,13 +184,13 @@ class LocalSearch():
                         
                         a, b = i, j # se guardan los indices del optimo local si se encuentra uno mejor
                         
-                        if self.bestImprovement: # cuando sea best improvement se sigue buscando por lo que se actualiza el mejor para esta busqueda
+                        if self.bestImprovement: # cuando sea best improvement se sigue buscando por lo que se actualiza el mejor para esta búsqueda
                             best_cost = tour.delta_cost_swap(tour.current, tour.cost, i, j)
                             
                         improved = True
                     else:
                         if self.options.verbose:
-                            details = f"{bcolors.OKBLUE} Solucion actual: {tour.cost}{bcolors.ENDC}"
+                            details = f"{bcolors.OKBLUE} Solución actual: {tour.cost}{bcolors.ENDC}"
                                             
                     # Agregar la informacion a la tabla
                     if details:
@@ -204,12 +204,12 @@ class LocalSearch():
                     end = timer() # tiempo actual de iteracion
                     
                         
-            if improved: # se encontro una mejora en la busqueda
+            if improved: # se encontro una mejora en la búsqueda
                 tour.swap(a, b)
                 self.best_tour.copy(tour)
                 best_cost = self.best_tour.cost
                 
-                details = f"{bcolors.OKGREEN} Solucion actual con mejor costo encontrada: {tour.cost}{bcolors.ENDC}"
+                details = f"{bcolors.OKGREEN} Solución actual con mejor costo encontrada: {tour.cost}{bcolors.ENDC}"
                 table.add_row([f"{bcolors.BOLD}{self.evaluations}", 
                                     f"{end-start:.4f}{bcolors.ENDC}", 
                                     f"{details}"
@@ -223,7 +223,7 @@ class LocalSearch():
                                     evaluations=self.evaluations) )
 
     
-        # actualizar tiempo total de busqueda 
+        # actualizar tiempo total de búsqueda 
         self.total_time = timer() - start
             
     """
@@ -236,7 +236,7 @@ class LocalSearch():
 
             
     def twoOptSearch(self, tour: Tour, table: PrettyTable = PrettyTable()) -> None:
-        """ Aplica la busqueda por 3-opt """
+        """ Aplica la búsqueda por 3-opt """
         #print(tour.current)   
         n = self.problem.getSize()
         if n < 3: 
@@ -265,13 +265,13 @@ class LocalSearch():
                         
                         a, b = i, j # se guardan los indices del optimo local si se encuentra uno mejor
                         
-                        if self.bestImprovement: # cuando sea best improvement se sigue buscando por lo que se actualiza el mejor para esta busqueda
+                        if self.bestImprovement: # cuando sea best improvement se sigue buscando por lo que se actualiza el mejor para esta búsqueda
                             best_cost = tour.delta_cost_two_opt(tour.current, tour.cost, i, j)
                             
                         improved = True
                     else:
                         if self.options.verbose:
-                            details = f"{bcolors.OKBLUE} Solucion actual: {tour.cost}{bcolors.ENDC}"
+                            details = f"{bcolors.OKBLUE} Solución actual: {tour.cost}{bcolors.ENDC}"
                                                    
                     # Agregar la informacion a la tabla
                     if details:
@@ -285,12 +285,12 @@ class LocalSearch():
                     end = timer() # tiempo actual de iteracion
                         
                         
-            if improved: # se encontro una mejora en la busqueda
+            if improved: # se encontro una mejora en la búsqueda
                 tour.twoOptSwap(a, b)
                 self.best_tour.copy(tour)
                 best_cost = self.best_tour.cost
                 
-                details = f"{bcolors.OKGREEN} Solucion actual con mejor costo encontrada: {tour.cost}{bcolors.ENDC}"
+                details = f"{bcolors.OKGREEN} Solución actual con mejor costo encontrada: {tour.cost}{bcolors.ENDC}"
                 table.add_row([f"{bcolors.BOLD}{self.evaluations}", 
                                     f"{end-start:.4f}{bcolors.ENDC}", 
                                     f"{details}"
@@ -303,7 +303,7 @@ class LocalSearch():
                                     iterations=self.evaluations, 
                                     evaluations=self.evaluations) )
     
-        # actualizar tiempo total de busqueda
+        # actualizar tiempo total de búsqueda
         self.total_time = timer() - start
         
 
@@ -316,7 +316,7 @@ class LocalSearch():
     """
     
     def threeOptSearch(self, tour: Tour, table: PrettyTable = PrettyTable()) -> None:
-        """ Aplica la busqueda por 3-opt """
+        """ Aplica la búsqueda por 3-opt """
         
         n = self.problem.getSize()
         if n < 4:
@@ -355,10 +355,10 @@ class LocalSearch():
                             self.best_tour.copy(tour)
                                    
                             improved = True
-                            details = f"{bcolors.OKGREEN} Solucion actual con mejor costo encontrada: {tour.cost}{bcolors.ENDC}"
+                            details = f"{bcolors.OKGREEN} Solución actual con mejor costo encontrada: {tour.cost}{bcolors.ENDC}"
                         else:
                             if self.options.verbose:     
-                                details = f"{bcolors.OKBLUE} Solucion actual: {tour.cost}{bcolors.ENDC}"
+                                details = f"{bcolors.OKBLUE} Solución actual: {tour.cost}{bcolors.ENDC}"
                             
                             
                         end = timer() # tiempo actual de iteracion
@@ -373,17 +373,17 @@ class LocalSearch():
                         self.evaluations += 1
 
                                                         
-        # actualizar tiempo total de busqueda
+        # actualizar tiempo total de búsqueda
         self.total_time = timer() - start
 
 
 
     def printSolFile(self, outputSol: str) -> None:
-        """ Guarda la solucion en archivo de texto """
+        """ Guarda la solución en archivo de texto """
         utilities.printSolToFile(outputSol, self.best_tour.current)
 
     def printTraFile(self, outputTra: str) -> None:
-        """ Guarda la trayectoria de la solucion en archivo de texto """
+        """ Guarda la trayectoria de la solución en archivo de texto """
         utilities.printTraToFile(outputTra, self.trajectory)
 
     def updateLog(self) -> None:
@@ -402,10 +402,10 @@ class LocalSearch():
             if not csvfile.tell():
                 writer.writeheader()
 
-            # crear texto con la solucion separando cada elemento con espacios y luego guardarlo en el archivo
+            # crear texto con la solución separando cada elemento con espacios y luego guardarlo en el archivo
             sol = " ".join([str(elem) for elem in self.best_tour.current])
 
-            # escribir la mejor solucion y todas las caracteristicas de su ejecucion
+            # escribir la mejor solución y todas las caracteristicas de su ejecucion
             writer.writerow({
                 "solution": sol, 
                 "cost": self.best_tour.cost, 
@@ -419,7 +419,7 @@ class LocalSearch():
             })
 
     def visualize(self) -> None:
-        """ Visualiza la trayectoria de la solucion """
+        """ Visualiza la trayectoria de la solución """
         plot.Graph.replit = self.options.replit
         plot.Graph.trajectory = self.trajectory
         
