@@ -8,7 +8,7 @@ from . import path, csv, datetime, Path, timer, math, PrettyTable
 from .. import Tour, Tsp, AlgorithmsOptions, CoolingType, InitialSolution, TSPMove
 
 class SimulatedAnnealing():
-    """ Clase Simulated Annealing la cual representa dicha metaheristica y sus metodos de busqueda
+    """ Clase Simulated Annealing la cual representa dicha metaheristica y sus metodos de búsqueda
 
         Parameters
         ----------
@@ -32,7 +32,7 @@ class SimulatedAnnealing():
         total_time : float
             Tiempo de ejecucion de Simulated Annealing
         trajectory : list
-            Lista de objetos de la trayectoria de la solucion
+            Lista de objetos de la trayectoria de la solución
 
         Examples
         --------
@@ -60,7 +60,7 @@ class SimulatedAnnealing():
 
         self.options: AlgorithmsOptions # Opciones
 
-        self.trajectory = [] # lista con la trayectoria de la solucion
+        self.trajectory = [] # lista con la trayectoria de la solución
         
         # Si por el objeto con las opciones no es enviado al iniciar la clase
         if not options:
@@ -83,22 +83,22 @@ class SimulatedAnnealing():
         print(f"{bcolors.HEADER}\nIniciando Simulated Annealing...{bcolors.ENDC}")
 
     def print_best_solution(self) -> None:
-        """ Escribir la mejor solucion """
+        """ Escribir la mejor solución """
         self.updateLog()
         print()
-        print(f"\t\t{bcolors.UNDERLINE}Mejor Solucion Encontrada{bcolors.ENDC}\n")
+        print(f"\t\t{bcolors.UNDERLINE}Mejor Solución Encontrada{bcolors.ENDC}\n")
         self.best_tour.printSol(True)
         print(f"{bcolors.BOLD}Total de evaluaciones:{bcolors.ENDC} {bcolors.OKBLUE}{self.evaluations-1}{bcolors.ENDC}")
-        print(f"{bcolors.BOLD}Tiempo total de busqueda con Simulated Annealing:{bcolors.ENDC} {bcolors.OKBLUE}{self.total_time:.3f} segundos{bcolors.ENDC}")
+        print(f"{bcolors.BOLD}Tiempo total de búsqueda con Simulated Annealing:{bcolors.ENDC} {bcolors.OKBLUE}{self.total_time:.3f} segundos{bcolors.ENDC}")
 
     def search(self, first_solution: Tour = None) -> None:
-        """ Ejecuta la busqueda de Simulated Annealing desde una solucion inicial """
+        """ Ejecuta la búsqueda de Simulated Annealing desde una solución inicial """
 
         table = PrettyTable()
 
         table.field_names = [f"{bcolors.BOLD}Iteraciones", "Temperatura", "Tiempo", f"Detalles{bcolors.ENDC}"]
 
-        # Si el atributo opcional de la solucion inicial no esta incluido
+        # Si el atributo opcional de la solución inicial no esta incluido
         if not first_solution:
             first_solution = Tour(type_initial_sol=self.options.initial_solution, problem=self.problem)
 
@@ -109,7 +109,7 @@ class SimulatedAnnealing():
         current_tour = Tour(tour=first_solution) # variable del tour actual 
         neighbor_tour = Tour(tour=first_solution) # variable del tour vecino generado 
         
-        self.best_tour.copy(first_solution) # solucion inicial se guarda como la mejor hasta el momento
+        self.best_tour.copy(first_solution) # solución inicial se guarda como la mejor hasta el momento
         # Guardar trayectoria Inicial
         self.trajectory.append( Trajectory(
                                 tour=self.best_tour.current.copy(),
@@ -125,7 +125,7 @@ class SimulatedAnnealing():
                                     evaluations=self.evaluations-1,
                                     temperature=temperature) ) 
                                 
-        print(f"{bcolors.UNDERLINE}\nComenzando busqueda, solucion inicial: {bcolors.ENDC}")
+        print(f"{bcolors.UNDERLINE}\nComenzando búsqueda, solución inicial: {bcolors.ENDC}")
         self.best_tour.printSol()
 
         # tiempo inicial para iteraciones y condicion de termino por tiempo
@@ -143,9 +143,9 @@ class SimulatedAnnealing():
             # Generar un vecino aleatoriamente a traves de un movimiento
             neighbor_tour.randomMove(self.move_type)
 
-            # Revisar funcion objetivo de la nueva solucion
+            # Revisar funcion objetivo de la nueva solución
             if (neighbor_tour.cost < current_tour.cost):
-                # Mejor solucion encontrada
+                # Mejor solución encontrada
                 current_tour.copy(neighbor_tour)
                 # Guardar trayectoria Final
                 self.trajectory.append( Trajectory(
@@ -163,21 +163,21 @@ class SimulatedAnnealing():
                 prob = self.getAcceptanceProbability(neighbor_tour.cost, current_tour.cost, temperature)
                 
                 if (utilities.random.random() <= prob):
-                    # Se acepta la solucion peor
+                    # Se acepta la solución peor
                     current_tour.copy(neighbor_tour)
                     
                    
-                    details += f"{bcolors.FAIL} Se acepta peor costo por crit. de metropolis: {neighbor_tour.cost}{bcolors.ENDC}"
+                    details += f"{bcolors.FAIL} Se acepta peor costo por crit. de metrópolis: {neighbor_tour.cost}{bcolors.ENDC}"
                 else:
-                   # No se acepta la solucion
-                    details += f"{bcolors.WARNING} No se acepta peor costo por crit. de metropolis: {neighbor_tour.cost}{bcolors.ENDC}{bcolors.OKGREEN} -> Solucion actual: {current_tour.cost}{bcolors.ENDC}"
+                   # No se acepta la solución
+                    details += f"{bcolors.WARNING} No se acepta peor costo por crit. de metrópolis: {neighbor_tour.cost}{bcolors.ENDC}{bcolors.OKGREEN} -> Solución actual: {current_tour.cost}{bcolors.ENDC}"
 
                     neighbor_tour.copy(current_tour)
 
-			# Revisar si la nueva solucion es la mejor hasta el momento
+			# Revisar si la nueva solución es la mejor hasta el momento
             if (current_tour.cost < self.best_tour.cost):
                
-                details += f"{bcolors.OKGREEN} -> ¡Mejor solucion global encontrada! {bcolors.ENDC}"
+                details += f"{bcolors.OKGREEN} -> ¡Mejor solución global encontrada! {bcolors.ENDC}"
 
                 self.best_tour.copy(current_tour)
 
@@ -193,7 +193,7 @@ class SimulatedAnnealing():
             self.evaluations += 1
             end = timer() # tiempo actual de iteracion
 
-        # actualizar tiempo total de busqueda de Simulated Annealing
+        # actualizar tiempo total de búsqueda de Simulated Annealing
         self.total_time = timer() - start
         # Guardar trayectoria Final
         self.trajectory.append( Trajectory(
@@ -231,15 +231,15 @@ class SimulatedAnnealing():
 		
 
     def getAcceptanceProbability (self, neighbor_cost: int, current_cost: int, temperature: float) -> float:
-        """ Funcion para obtener una probabilidad aplicando el criterio de metropolis e^-(delta/temp)"""
+        """ Obtener una probabilidad aplicando el criterio de metrópolis e^-(delta/temp)"""
         # determinar delta
         delta = neighbor_cost - current_cost
-        # Aplicar y retornar la formula para el criterio de metropolis
+        # Aplicar y retornar la formula para el criterio de metrópolis
         return math.e**-(delta / temperature) 
 
 
     def reduceTemperature(self, temperature: float, evaluation: int) -> float:
-        """ Funcion que reduce la temperatura de Simulated Annealing"""
+        """ Reduce la temperatura de Simulated Annealing"""
         t_new = temperature
         if (self.cooling == CoolingType.GEOMETRIC):
             t_new *= self.options.alpha
@@ -253,11 +253,11 @@ class SimulatedAnnealing():
         return t_new
 
     def printSolFile(self, outputSol: str) -> None:
-        """ Guarda la solucion en archivo de texto"""
+        """ Guarda la solución en archivo de texto"""
         utilities.printSolToFile(outputSol, self.best_tour.current)
 
     def printTraFile(self, outputTra: str) -> None:
-        """ Guarda la trayectoria de la solucion en archivo de texto"""
+        """ Guarda la trayectoria de la solución en archivo de texto"""
         utilities.printTraToFile(outputTra, self.trajectory)
 
     def updateLog(self) -> None:
@@ -277,10 +277,10 @@ class SimulatedAnnealing():
             if not csvfile.tell():
                 writer.writeheader()
 
-            # crear texto con la solucion separando cada elemento con espacios y luego guardarlo en el archivo
+            # crear texto con la solución separando cada elemento con espacios y luego guardarlo en el archivo
             sol = " ".join([str(elem) for elem in self.best_tour.current])
 
-            # escribir la mejor solucion y todas las caracteristicas de su ejecucion
+            # escribir la mejor solución y todas las caracteristicas de su ejecucion
             writer.writerow({
                 "solution": sol, 
                 "cost": self.best_tour.cost, 
@@ -298,7 +298,7 @@ class SimulatedAnnealing():
             })
 
     def visualize(self) -> None:
-        """ Visualiza la trayectoria de la solucion """
+        """ Visualiza la trayectoria de la solución """
         plot.Graph.replit = self.options.replit
         plot.Graph.trajectory = self.trajectory
         
