@@ -31,10 +31,10 @@ class TSPMove(Enum):
 """ S I M U L A T E D  A N N E A L I N G """
 
 class InitialSolution(Enum):
-    """ Metodos disponibles para crear una solucion inicial
-    RANDOM: Solucion aleatoria
-    NEAREST_N: Solucion creada con la heuristica del vecino mas cercano
-    DETERMINISTIC: Solucion creada deterministicamente para testing, en este caso es secuencial
+    """ Metodos disponibles para crear una solución inicial
+    RANDOM: Solución aleatoria
+    NEAREST_N: Solución creada con la heuristica del vecino mas cercano
+    DETERMINISTIC: Solución creada deterministicamente para testing, en este caso es secuencial
     """
     RANDOM = 'RANDOM'
     NEAREST_N = 'NEAREST_N'
@@ -53,11 +53,11 @@ class CoolingType(Enum):
 """ A L G O R I T M O   G E N E T I C O """
 
 class SelectionType(Enum):
-    """Tipos de seleccion de individuos
-        RANDOM: Seleccion aleatoria
-        BEST: Seleccion de los mejores (elitismo)
-        ROULETTE: Seleccion proporcional al fitness
-        TOURNAMENT: Seleccion de torneos k=3
+    """Tipos de selección de individuos
+        RANDOM: Selección aleatoria
+        BEST: Selección de los mejores (elitismo)
+        ROULETTE: Selección proporcional al fitness
+        TOURNAMENT: Selección de torneos k=3
     """
     RANDOM = 'RANDOM'
     BEST = 'BEST'
@@ -75,7 +75,7 @@ class CrossoverType(Enum):
     OPX = 'OPX'
 
 class SelectionStrategy(Enum):
-    """Estrategias de seleccion de individuos de la poblacion
+    """Estrategias de selección de individuos de la población
     MU_LAMBDA: Estrategia (mu, lambda)
     MUPLUSLAMBDA: Estrategia (mu+lambda)
     """
@@ -85,7 +85,7 @@ class SelectionStrategy(Enum):
 """ L O C A L  S E A R C H  E  I T E R A T E D  L O C A L  S E A R C H """  
     
 class PerturbationType(Enum):
-    """Tipos de movimientos de perturbacion para Iterated Local Search
+    """Tipos de movimientos de perturbación para Iterated Local Search
     TWO_OPT: Operador 2-opt
     THREE_OPT: Operador 3-opt
     SWAP: Operador swap
@@ -103,41 +103,41 @@ class AlgorithmsOptions():
     Attributes
     ----------
     output : str
-        Archivo para imprimir la solucion
+        Archivo para imprimir la solución
     instance : str
         Archivo de la instancia TSP con formato TSPLib
     seed : int
-        Semilla para el generador de numero aleatorios
+        Semilla para el generador de números aleatorios
     metaheuristic : Enum
-        Tipo de metaheuristica a ejecutar SA o GA
+        Tipo de metaheurística a ejecutar SA o GA
     move : Enum
-        Tipo del movimiento para la metaheuristica
+        Tipo del movimiento para la metaheurística
     max_evaluations : int
-        Evaluaciones maximas 
+        Evaluaciones máximas 
     alpha : float
-        Parametro alfa para el enfriamiento de SA
+        Parámetro alfa para el enfriamiento de SA
     t0 : float
         Temperatura inicial para SA
     tmin : float
-        Temperatura minima para SA
+        Temperatura mínima para SA
     cooling : Enum
         Tipo de enfriamiento para SA
     pop_size : int
-        Tamaño de la poblacion 
+        Tamaño de la población 
     offspring_size : int
         Cantidad de hijos      
     pselection_type : Enum
-        Seleccion de padres       
+        Selección de padres       
     crossover_type : Enum
         Cruzamiento
     mutation_type : Enum
         Mutacion
     mutation_prob : float
-        Probabilidad de mutacion
+        Probabilidad de mutación
     selection_strategy : Enum
-        Estrategia de seleccion de la nueva poblacion
+        Estrategia de selección de la nueva población
     gselection_type : Enum
-        Seleccion de la nueva poblacion
+        Selección de la nueva población
     Methods
     -------
     __init__(args: list, **kwargs: dict)
@@ -153,30 +153,30 @@ class AlgorithmsOptions():
     gaArgs(args :any, kwargs: dict)
         Procesar los argumentos de Algoritmo Genetico
     printOptions()
-        Mostrar las opciones y parametros finales
+        Mostrar las opciones y parámetros finales
     """
     
     """ O P C I O N E S  G E N E R A L E S """
     
-    solution = "output/solution.txt"	# Archivo para imprimir la solucion
+    solution = "output/solution.txt"	# Archivo para imprimir la solución
 
-    trajectory = "output/trajectory.csv"	# Archivo para imprimir la trayectoria de solucion
+    trajectory = "output/trajectory.csv"	# Archivo para imprimir la trayectoria de solución
     
     instance = "instances/burma14.tsp" # Archivo de la instancia    
     
-    seed = 0 # Semilla para el generador de numero aleatorios    
+    seed = 0 # Semilla para el generador de número aleatorios    
      
-    metaheuristic = MHType.SA # Tipo de metaheuristica a ejecutar   
+    metaheuristic = MHType.SA # Tipo de metaheurística a ejecutar   
      
-    move = TSPMove.TWO_OPT # Tipo del movimiento para la metaheuristica o bien tipo de busqueda Local Search
+    move = TSPMove.TWO_OPT # Tipo del movimiento para la metaheurística o bien tipo de busqueda Local Search
     
-    max_evaluations = 1000 # Evaluaciones maximas
+    max_evaluations = 1000 # Evaluaciones máximas
     
-    max_iterations = 20 # Numero de iteraciones maximas
+    max_iterations = 20 # Numero de iteraciones máximas
     
-    max_time = 60.0 # Tiempo de ejecucion maximo
+    max_time = 60.0 # Tiempo de ejecucion máximo
     
-    initial_solution = InitialSolution.RANDOM # Solucion Inicial
+    initial_solution = InitialSolution.RANDOM # Solución Inicial
     
     silent = False # Modo silencioso
 
@@ -190,31 +190,31 @@ class AlgorithmsOptions():
     
     """ O P C I O N E S  P A R A  S I M U L A T E D  A N N E A L I N G """
     
-    alpha = 0.98 # Parametro alfa para el enfriamiento
+    alpha = 0.98 # Parámetro alfa para el enfriamiento
     
     t0 = 1000.0 # Temperatura inicial 
     
-    tmin = 900.0 # Temperatura minima    
+    tmin = 900.0 # Temperatura mínima    
     
     cooling = CoolingType.GEOMETRIC # Tipo de enfriamiento
 
     """ O P C I O N E S   P A R A   A L G O R I T M O   G E N E T I C O """
     
-    pop_size = 10 # Cantidad de individuos de la poblacion 
+    pop_size = 10 # Cantidad de individuos de la población 
 	
     offspring_size = 20 # Cantidad de hijos
     
-    pselection_type = SelectionType.RANDOM # Seleccion de padres
+    pselection_type = SelectionType.RANDOM # Selección de padres
     
     crossover_type = CrossoverType.OX # Cruzamiento
     
     mutation_type = TSPMove.SWAP # Mutacion
     
-    mutation_prob = 0.2 # probabilidad de mutacion 
+    mutation_prob = 0.2 # probabilidad de mutación 
     
-    selection_strategy = SelectionStrategy.MULAMBDA # Estrategia de seleccion de la nueva poblacion
+    selection_strategy = SelectionStrategy.MULAMBDA # Estrategia de selección de la nueva población
     
-    gselection_type = SelectionType.RANDOM # Seleccion de la nueva poblacion
+    gselection_type = SelectionType.RANDOM # Selección de la nueva población
     
     """ O P C I O N E S   P A R A   L O C A L  S E A R C H  E  I T E R A T E D  L O C A L  S E A R C H """
     
@@ -226,7 +226,7 @@ class AlgorithmsOptions():
 
     def __init__(self, argv=[], **kwargs) -> None:
 
-        # Semilla para el generador de numeros aleatorios
+        # Semilla para el generador de números aleatorios
         self.seed = round(time.time() * 1000)
         
         # Leer argumentos que vengan por parametro o por definicion
@@ -244,49 +244,49 @@ class AlgorithmsOptions():
         if (len(argv) == 1 or not argv):
             print(f"{bcolors.WARNING}Warning: usando instancia por defecto: {self.instance} {bcolors.ENDC}")
             print(f"{bcolors.WARNING}Si desea utilizar otra instancia debe proporcionarla (use -i o --instance <file_path>) {bcolors.ENDC}")
-            print(f"{bcolors.WARNING}Use el argumento '-h' o '--help' para mayor informacion {bcolors.ENDC}")
+            print(f"{bcolors.WARNING}Use el argumento '-h' o '--help' para mayor información {bcolors.ENDC}")
         
         parser = argparse.ArgumentParser()
         # Declarar y definir argumentos
         # Definir argumentos generales
         parser.add_argument("-s", "--silent", help="Ejecuta sin mostrar los cambios en cada ciclo de los algoritmos", action="store_true")
-        parser.add_argument("-vi", "--visualize", help="Muestra la visualizacion de trayectoria a la mejor solucion de forma grafica", action="store_true")
-        parser.add_argument("-re", "--replit", help="Si se ejecuta en Replit.com ya que la visualizacion puede tener inconvenientes", action="store_true")
-        parser.add_argument("-v", "--verbose", help="Ejecuta mostrando todos los detalles de cada iteracion", action="store_true")
+        parser.add_argument("-vi", "--visualize", help="Muestra la visualización de trayectoria a la mejor solución de forma grafica", action="store_true")
+        parser.add_argument("-re", "--replit", help="Si se ejecuta en Replit.com ya que la visualización puede tener inconvenientes", action="store_true")
+        parser.add_argument("-v", "--verbose", help="Ejecuta mostrando todos los detalles de cada iteración", action="store_true")
         parser.add_argument("-gui", "--gui", help="Ejecuta en modo interfaz grafica", action="store_true")
 
                 
         parser.add_argument("-mh", "--metaheuristic", help="Tipo de Metaherisitica a usar:\n SA: Simulated Annealing\n GA: Genetic Algorithm\n LS: Local Search")
         parser.add_argument("-al", "--algorithm", help="Tipo de Algoritmo a usar:\n SA: Simulated Annealing\n GA: Genetic Algorithm\n LS: Local Search")
         parser.add_argument("-i", "--instance", help="Archivo con la instancia a utilizar en formato TSPLIB")
-        parser.add_argument("-se", "--seed", help="Numero para ser usado como semilla para el generador de numeros aleatorios")
-        parser.add_argument("-sol", "--solution", help="Nombre del archivo de salida para la solucion y trayectoria")
+        parser.add_argument("-se", "--seed", help="Numero para ser usado como semilla para el generador de números aleatorios")
+        parser.add_argument("-sol", "--solution", help="Nombre del archivo de salida para la solución y trayectoria")
         parser.add_argument("-mhm", "--move", help="Tipo de movimiento a utilizar en la heuristica [ 2opt | swap | 3opt ]")
-        parser.add_argument("-e", "--evaluations", help="Numero maximo de soluciones a evaluar")
-        parser.add_argument("-it", "--iterations", help="Numero maximo de iteraciones a realizar")
+        parser.add_argument("-e", "--evaluations", help="Numero máximo de soluciones a evaluar")
+        parser.add_argument("-it", "--iterations", help="Numero máximo de iteraciones a realizar")
         parser.add_argument("-t", "--time", help="Limite de tiempo de ejecucion en segundos")
 
         # Definir argumentos de Simulated Annealing
-        parser.add_argument("-is", "--insol", help="Solucion inicial [ RANDOM | NEAREST_N | DETERMINISTIC ]")
-        parser.add_argument("-a", "--alpha", help="Parametro alfa para el esquema geometrico ]0,1]")
+        parser.add_argument("-is", "--insol", help="Solución inicial [ RANDOM | NEAREST_N | DETERMINISTIC ]")
+        parser.add_argument("-a", "--alpha", help="Parámetro alfa para el esquema geometrico ]0,1]")
         parser.add_argument("-t0", "--tini", help="Temperatura inicial ]0,DOUBLE_MAX]")
-        parser.add_argument("-tm", "--tmin", help="Temperatura minima ]0,DOUBLE_MAX]")
+        parser.add_argument("-tm", "--tmin", help="Temperatura mínima ]0,DOUBLE_MAX]")
         parser.add_argument("-c", "--cooling", help="Esquema de enfriamiento de la temperatura [ geometric | log | linear ]")
 
         # Definir argumentos de Algoritmo Genetico
-        parser.add_argument("-p", "--psize", help="Cantidad de individuos de la poblacion ]0,INT_MAX]")
+        parser.add_argument("-p", "--psize", help="Cantidad de individuos de la población ]0,INT_MAX]")
         parser.add_argument("-o", "--osize", help="Cantidad de hijos a generar ]0,INT_MAX]")
-        parser.add_argument("-ps", "--pselection", help="Operador de seleccion de padres [ random | best | roulette | tournament ]")
+        parser.add_argument("-ps", "--pselection", help="Operador de selección de padres [ random | best | roulette | tournament ]")
         parser.add_argument("-cr", "--crossover", help="Operador de crossover [ ox | opx | pmx ]")
-        parser.add_argument("-mu", "--mutation", help="Operador de mutacion [ swap | 2opt | 3opt ]")
-        parser.add_argument("-mp", "--mprobability", help="Probabilidad de mutacion [0.0,1.0]")
-        parser.add_argument("-gs", "--gselection", help="Operador de seleccion de poblacion [ random | best | roulette | tournament ]")
-        parser.add_argument("-g", "--gstrategy", help="Estrategia de seleccion de padres [ mu,lambda | mu+lambda ]")
+        parser.add_argument("-mu", "--mutation", help="Operador de mutación [ swap | 2opt | 3opt ]")
+        parser.add_argument("-mp", "--mprobability", help="Probabilidad de mutación [0.0,1.0]")
+        parser.add_argument("-gs", "--gselection", help="Operador de selección de población [ random | best | roulette | tournament ]")
+        parser.add_argument("-g", "--gstrategy", help="Estrategia de selección de padres [ mu,lambda | mu+lambda ]")
         
         # Definir argumentos de Local Search e Iterated Local Search
         parser.add_argument("-b", "--best", help="Ejecuta Local Search en modo best improvement", action="store_true")
-        parser.add_argument("-per", "--perturbation", help="Tipo de perturbacion a aplicar en ITS [ 2opt | swap | 3opt ]")
-        parser.add_argument("-np", "--nperturbations", help="Cantidad de perturbaciones a aplicar en una iteracion ]0,INT_MAX]")
+        parser.add_argument("-per", "--perturbation", help="Tipo de perturbación a aplicar en ITS [ 2opt | swap | 3opt ]")
+        parser.add_argument("-np", "--nperturbations", help="Cantidad de perturbaciones a aplicar en cada iteración de Iterated Local Search ]0,INT_MAX]")
         
         # Procesar argumentos
         args = parser.parse_args()
@@ -318,16 +318,16 @@ class AlgorithmsOptions():
             try:
                 self.max_time = float(args.time) if args.time else float(kwargs['time'])
             except: 
-                print(f"{bcolors.FAIL}Error: El tiempo maximo debe ser un numero (-t | --time){bcolors.ENDC}")
+                print(f"{bcolors.FAIL}Error: El tiempo máximo debe ser un número (-t | --time){bcolors.ENDC}")
 
         # Semilla 
         if (args.seed or 'seed' in kwargs):
             try:
                 self.seed = int(args.seed) if args.seed else int(kwargs['seed'])
             except: 
-                print(f"{bcolors.FAIL}Error: La semilla debe ser un numero entero (-s | --seed){bcolors.ENDC}")
+                print(f"{bcolors.FAIL}Error: La semilla debe ser un número entero (-s | --seed){bcolors.ENDC}")
 
-        # Archivo de salida para solucion y trayectoria
+        # Archivo de salida para solución y trayectoria
         if (args.solution or 'solution' in kwargs):
             self.solution = args.solution if args.solution else kwargs['solution']
             self.trajectory = args.solution if args.solution else kwargs['solution']
@@ -360,7 +360,7 @@ class AlgorithmsOptions():
         if (args.instance or 'instance' in kwargs):
             self.instance = args.instance if args.instance else kwargs['instance']
 
-        # Seleccion de Metaheuristica
+        # Selección de Metaheuristica
         if (args.metaheuristic or 'metaheuristic' in kwargs):
             val = args.metaheuristic.upper() if args.metaheuristic else kwargs['metaheuristic'].upper()
             if (val == 'SA'):
@@ -373,21 +373,21 @@ class AlgorithmsOptions():
                 self.metaheuristic = MHType.ILS
             else: print(f"{bcolors.FAIL}Error: Metaheuristica no reconocida (-mh | --metaheristic) {bcolors.ENDC}")  
         
-        # Numero maximo de evaluaciones
+        # Numero máximo de evaluaciones
         if (args.evaluations or 'evaluations' in kwargs):
             try:
                 self.max_evaluations = int(args.evaluations) if args.evaluations else int(kwargs['evaluations'])
             except: 
-                print(f"{bcolors.FAIL}Error: El numero de evaluaciones debe ser un numero entero (-e | --evaluations) {bcolors.ENDC}")
+                print(f"{bcolors.FAIL}Error: El número de evaluaciones debe ser un número entero (-e | --evaluations) {bcolors.ENDC}")
 
-        # Numero maximo de iteraciones
+        # Numero máximo de iteraciones
         if (args.iterations or 'iterations' in kwargs):
             try:
                 self.max_iterations = int(args.iterations) if args.iterations else int(kwargs['iterations'])
             except: 
-                print(f"{bcolors.FAIL}Error: El numero de iteraciones debe ser un numero entero (-it | --iterations) {bcolors.ENDC}")
+                print(f"{bcolors.FAIL}Error: El número de iteraciones debe ser un número entero (-it | --iterations) {bcolors.ENDC}")
 
-        # Seleccion del movimiento para la metaheuristica
+        # Selección del movimiento para la metaheurística
         if (args.move or 'move' in kwargs):
             val = args.move.lower() if args.move else kwargs['move'].lower()
             if (val == '2opt' or val == '2-opt'):
@@ -398,7 +398,7 @@ class AlgorithmsOptions():
                 self.move = TSPMove.SWAP
             else: print(f"{bcolors.FAIL}Error: Tipo de movimiento no reconocido (-mhm | --move) {bcolors.ENDC}") 
             
-        # Solucion inicial
+        # Solución inicial
         if (args.insol or 'insol' in kwargs):
             val = args.insol.upper() if args.insol else kwargs['insol'].upper()
             if (val == 'RANDOM'):
@@ -407,7 +407,7 @@ class AlgorithmsOptions():
                 self.initial_solution = InitialSolution.NEAREST_N
             elif (val == 'DETERMINISTIC'):
                 self.initial_solution = InitialSolution.DETERMINISTIC
-            else: print(f"{bcolors.FAIL}Error: Opcion no reconocida en solucion inicial (-is | --inso) {bcolors.ENDC}")
+            else: print(f"{bcolors.FAIL}Error: Opcion no reconocida en solución inicial (-is | --inso) {bcolors.ENDC}")
 
         # Modo de salida reducido para no mostrar todos los cambios en los ciclos de los algoritmos
         if (args.silent):
@@ -417,7 +417,7 @@ class AlgorithmsOptions():
     def argsSA(self, args: argparse.Namespace, kwargs: dict) -> None:
         """Procesar los argumentos de Simulated Annealing"""
 
-        # Seleccion del esquema de enfriamiento
+        # Selección del esquema de enfriamiento
         if (args.cooling or 'cooling' in kwargs):
             val = args.cooling.lower() if args.cooling else kwargs['cooling'].lower()
             if (val == 'geometric'):
@@ -428,45 +428,45 @@ class AlgorithmsOptions():
                 self.cooling = CoolingType.LINEAR    
             else: print(f"{bcolors.FAIL}Error: Opcion no reconocida en COOLING (-tc | --cooling) {bcolors.ENDC}")    
 
-        # Parametro alpha
+        # Parámetro alpha
         if (args.alpha or 'alpha' in kwargs):
             try:
                 self.alpha = float(args.alpha) if args.alpha else float(kwargs['alpha'])
             except: 
-                print(f"{bcolors.FAIL}Error: El valor de alpha debe ser un numero en (-a | --alpha) {bcolors.ENDC}")
+                print(f"{bcolors.FAIL}Error: El valor de alpha debe ser un número en (-a | --alpha) {bcolors.ENDC}")
         
         # Temperatura inicial
         if (args.tini or 'tini' in kwargs):
             try:
                 self.t0 = float(args.tini) if args.tini else float(kwargs['tini'])
             except:
-                print(f"{bcolors.FAIL}Error: El valor de la temperatura inicial debe ser un numero (-t0 | --tini) {bcolors.ENDC}")
+                print(f"{bcolors.FAIL}Error: El valor de la temperatura inicial debe ser un número (-t0 | --tini) {bcolors.ENDC}")
 
-        # Temperatura minima
+        # Temperatura mínima
         if (args.tmin or 'tmin' in kwargs):
             try:
                 self.tmin = float(args.tmin) if args.tmin else float(kwargs['tmin'])
             except:
-                print(f"{bcolors.FAIL}Error: El valor de la temperatura minima debe ser un numero (-tmin | --tmin) {bcolors.ENDC}")
+                print(f"{bcolors.FAIL}Error: El valor de la temperatura mínima debe ser un número (-tmin | --tmin) {bcolors.ENDC}")
 
 
     def argsGA(self, args: argparse.Namespace, kwargs: dict) -> None:
         """Procesar los argumentos de Algoritmo Genetico"""
-        # Cantidad de individuos de la poblacion
+        # Cantidad de individuos de la población
         if (args.psize or 'psize' in kwargs):
             try:
                 self.pop_size = int(args.psize) if args.psize else int(kwargs['psize'])
             except: 
-                print(f"{bcolors.FAIL}Error: El tamaño de la poblacion debe ser un numero entero (-p | --psize){bcolors.ENDC}")
+                print(f"{bcolors.FAIL}Error: El tamaño de la población debe ser un número entero (-p | --psize){bcolors.ENDC}")
 
         # Cantidad de hijos a generar
         if (args.osize or 'osize' in kwargs):
             try:
                 self.offspring_size = int(args.osize) if args.osize else int(kwargs['osize'])
             except: 
-                print(f"{bcolors.FAIL}Error: La cantidad de hijos debe ser un numero entero (-o | --osize){bcolors.ENDC}")
+                print(f"{bcolors.FAIL}Error: La cantidad de hijos debe ser un número entero (-o | --osize){bcolors.ENDC}")
 
-        # Seleccion de padres
+        # Selección de padres
         if (args.pselection or 'pselection' in kwargs):
             val = args.pselection.lower() if args.pselection else kwargs['pselection'].lower()
             if (val == 'random'):
@@ -477,7 +477,7 @@ class AlgorithmsOptions():
                 self.pselection_type = SelectionType.ROULETTE
             elif (val == 'tournament'):
                 self.pselection_type = SelectionType.TOURNAMENT   
-            else: print(f"{bcolors.FAIL}Error: Opcion no reconocida en Seleccion de padres (-ps | --pselection) {bcolors.ENDC}")
+            else: print(f"{bcolors.FAIL}Error: Opcion no reconocida en Selección de padres (-ps | --pselection) {bcolors.ENDC}")
         
         # Operador de Cruzamiento
         if (args.crossover or 'crossover' in kwargs):
@@ -490,7 +490,7 @@ class AlgorithmsOptions():
                 self.crossover_type = CrossoverType.PMX
             else: print(f"{bcolors.FAIL}Error: Opcion no reconocida en Operador de Cruzamiento (-o | --crossover) {bcolors.ENDC}")
 
-        # Operador de mutacion
+        # Operador de mutación
         if (args.mutation or 'mutation' in kwargs):
             val = args.mutation.lower() if args.mutation else kwargs['mutation'].lower()
             if (val == '2opt' or val == '2-opt'):
@@ -499,16 +499,16 @@ class AlgorithmsOptions():
                 self.mutation_type = TSPMove.THREE_OPT
             elif (val == 'swap'):
                 self.mutation_type = TSPMove.SWAP
-            else: print(f"{bcolors.FAIL}Error: Tipo de mutacion no reconocido (-mu | --mutation) {bcolors.ENDC}")
+            else: print(f"{bcolors.FAIL}Error: Tipo de mutación no reconocido (-mu | --mutation) {bcolors.ENDC}")
 
-        # Probabilidad de mutacion
+        # Probabilidad de mutación
         if (args.mprobability or 'mprobability' in kwargs):
             try:
                 self.mutation_prob = float(args.mprobability) if args.mprobability else float(kwargs['mprobability'])
             except: 
-                print(f"{bcolors.FAIL}Error: El valor de probabilidad de mutacion debe ser un numero en (-mp | --mprobability) {bcolors.ENDC}")
+                print(f"{bcolors.FAIL}Error: El valor de probabilidad de mutación debe ser un número en (-mp | --mprobability) {bcolors.ENDC}")
         
-        # Operador de seleccion de poblacion
+        # Operador de selección de población
         if (args.gselection or 'gselection' in kwargs):
             val = args.gselection.lower() if args.gselection else kwargs['gselection'].lower()
             if (val == 'random'):
@@ -519,22 +519,22 @@ class AlgorithmsOptions():
                 self.gselection_type = SelectionType.ROULETTE
             elif (val == 'tournament'):
                 self.gselection_type = SelectionType.TOURNAMENT   
-            else: print(f"{bcolors.FAIL}Error: Opcion no reconocida en Seleccion de poblacion (-gs | --gselection) {bcolors.ENDC}")
+            else: print(f"{bcolors.FAIL}Error: Opcion no reconocida en Selección de población (-gs | --gselection) {bcolors.ENDC}")
 
-        # Estrategia de seleccion de padres
+        # Estrategia de selección de padres
         if (args.gstrategy or 'gstrategy' in kwargs):
             val = args.gstrategy.lower() if args.gstrategy else kwargs['gstrategy'].lower()
             if (val == 'mu,lambda'):
                 self.selection_strategy = SelectionStrategy.MULAMBDA
             elif (val == 'mu+lambda'):
                 self.selection_strategy = SelectionStrategy.MUPLUSLAMBDA
-            else: print(f"{bcolors.FAIL}Error: Tipo de seleccion de padres no reconocido (-g | --gstrategy) {bcolors.ENDC}")
+            else: print(f"{bcolors.FAIL}Error: Tipo de selección de padres no reconocido (-g | --gstrategy) {bcolors.ENDC}")
             
             
     def argsLS(self, args: argparse.Namespace, kwargs: dict) -> None:
         """Procesar argumentos de Local Search"""
         
-        # Seleccion del movimiento para la metaheuristica
+        # Selección del movimiento para la metaheurística
         if (args.perturbation or 'perturbation' in kwargs):
             val = args.perturbation.lower() if args.move else kwargs['perturbation'].lower()
             if (val == '2opt' or val == '2-opt'):
@@ -545,7 +545,7 @@ class AlgorithmsOptions():
                 self.perturbation = PerturbationType.SWAP
             elif (val == 'random'):
                 self.perturbation = PerturbationType.RANDOM
-            else: print(f"{bcolors.FAIL}Error: Tipo de perturbacion no reconocido (-per | --perturbation) {bcolors.ENDC}")
+            else: print(f"{bcolors.FAIL}Error: Tipo de perturbación no reconocido (-per | --perturbation) {bcolors.ENDC}")
         
         # Si se ejecuta en Replit.com
         if (args.best or 'best' in kwargs):
@@ -556,17 +556,17 @@ class AlgorithmsOptions():
             try:
                 self.nPerturbations = int(args.nperturbations) if args.nperturbations else int(kwargs['nperturbations'])
             except: 
-                print(f"{bcolors.FAIL}Error: El numero de perturbaciones debe ser un numero entero (-np | --nperturbations){bcolors.ENDC}")
+                print(f"{bcolors.FAIL}Error: El número de perturbaciones debe ser un número entero (-np | --nperturbations){bcolors.ENDC}")
 
 
     def errorsSA(self) -> bool:
-        """ Validar que algunos parametros cumplan con la logica del algoritmo a aplicar """
+        """ Validar que algunos parámetros cumplan con la lógica del algoritmo a aplicar """
         error = False
         if (self.max_evaluations <= 0 or self.max_iterations <= 0):
-            print(f"{bcolors.FAIL}Error: iteraciones o evaluaciones maximas deben ser > 0 Iteraciones: {self.max_iterations} Evaluaciones: {self.max_evaluations}{bcolors.ENDC}")
+            print(f"{bcolors.FAIL}Error: iteraciones o evaluaciones máximas deben ser > 0 Iteraciones: {self.max_iterations} Evaluaciones: {self.max_evaluations}{bcolors.ENDC}")
             error = True
         if (self.tmin <= 0 or self.t0 <= 0):
-            print(f"{bcolors.FAIL}Error: Las temperatura minima y la temperatura inicial maximas deben ser > 0, tmin: {self.tmin} t0: {self.t0} evaluaciones: {self.max_evaluations} {bcolors.ENDC}")
+            print(f"{bcolors.FAIL}Error: Las temperatura mínima y la temperatura inicial máximas deben ser > 0, tmin: {self.tmin} t0: {self.t0} evaluaciones: {self.max_evaluations} {bcolors.ENDC}")
             error = True
         if (self.alpha <= 0 or self.alpha > 1):
             print(f"{bcolors.FAIL}Error: alfa debe ser > 0 y <= 1, valor: {self.alpha} (-a | --alpha){bcolors.ENDC}")
@@ -577,19 +577,19 @@ class AlgorithmsOptions():
         return error
     
     def errorsGA(self) -> bool:
-        """ Validar que algunos parametros cumplan con la logica del algoritmo a aplicar """
+        """ Validar que algunos parámetros cumplan con la logica del algoritmo a aplicar """
         error = False
         if (self.max_evaluations <= 0 or self.max_iterations <= 0):
-            print(f"{bcolors.FAIL}Error: iteraciones o evaluaciones maximas deben ser > 0 Iteraciones: {self.max_iterations} Evaluaciones: {self.max_evaluations}{bcolors.ENDC}")
+            print(f"{bcolors.FAIL}Error: iteraciones o evaluaciones máximas deben ser > 0 Iteraciones: {self.max_iterations} Evaluaciones: {self.max_evaluations}{bcolors.ENDC}")
             error = True
         if (self.mutation_prob > 1.0 or self.mutation_prob < 0.0 ):
-            print(f"{bcolors.FAIL}Error: La probabilidad de mutacion debe ser [0.0, 1.0]: {self.mutation_prob}{bcolors.ENDC}")
+            print(f"{bcolors.FAIL}Error: La probabilidad de mutación debe ser [0.0, 1.0]: {self.mutation_prob}{bcolors.ENDC}")
             error = True
         if (self.selection_strategy == SelectionStrategy.MULAMBDA and self.pop_size > self.offspring_size):
-            print(f"{bcolors.FAIL}Error: En (mu,lambda) la poblacion (-p | --psize) debe ser >= que los hijos (-o | --osize){bcolors.ENDC}")
+            print(f"{bcolors.FAIL}Error: En (mu,lambda) la población (-p | --psize) debe ser >= que los hijos (-o | --osize){bcolors.ENDC}")
             error = True
         if (self.pop_size <= 1):
-            print(f"{bcolors.FAIL}Error: La cantidad de individuos de la poblacion (-p | --psize) debe ser > 1{bcolors.ENDC}")
+            print(f"{bcolors.FAIL}Error: La cantidad de individuos de la población (-p | --psize) debe ser > 1{bcolors.ENDC}")
             error = True     
         return error
     
@@ -604,43 +604,42 @@ class AlgorithmsOptions():
     
     
     def printOptions(self) -> None:
-        """ Mostrar las opciones y parametros finales """
+        """ Mostrar las opciones y parámetros finales """
         # Opciones generales
         print(f"{bcolors.HEADER}\n\t\tOPCIONES GENERALES\n {bcolors.ENDC}")        
         print(f"{bcolors.OKBLUE}Archivo de instancia: {bcolors.ENDC}{self.instance}")
-        print(f"{bcolors.OKBLUE}Archivo para imprimir la solucion: {bcolors.ENDC}{self.solution}")
-        print(f"{bcolors.OKBLUE}Tipo de metaheuristica a ejecutar: {bcolors.ENDC}{self.metaheuristic.value}")
-        print(f"{bcolors.OKBLUE}Tipo del movimiento para la metaheuristica: {bcolors.ENDC}{self.move.value}")
-        print(f"{bcolors.OKBLUE}Semilla para el generador de numero aleatorios: {bcolors.ENDC}{self.seed}")
-        print(f"{bcolors.OKBLUE}Evaluaciones maximas: {bcolors.ENDC}{self.max_evaluations}")
-        print(f"{bcolors.OKBLUE}Iteraciones maximas: {bcolors.ENDC}{self.max_iterations}")
-        print(f"{bcolors.OKBLUE}Solucion Inicial: {bcolors.ENDC}{self.initial_solution.value}")
-        print(f"{bcolors.OKBLUE}Limite de tiempo de ejecucion: {bcolors.ENDC}{self.max_time} segundos")
+        print(f"{bcolors.OKBLUE}Archivo para imprimir la solución: {bcolors.ENDC}{self.solution}")
+        print(f"{bcolors.OKBLUE}Tipo de metaheurística a ejecutar: {bcolors.ENDC}{self.metaheuristic.value}")
+        print(f"{bcolors.OKBLUE}Tipo del movimiento para la metaheurística: {bcolors.ENDC}{self.move.value}")
+        print(f"{bcolors.OKBLUE}Semilla para el generador de números aleatorios: {bcolors.ENDC}{self.seed}")
+        print(f"{bcolors.OKBLUE}Evaluaciones máximas: {bcolors.ENDC}{self.max_evaluations}")
+        print(f"{bcolors.OKBLUE}Iteraciones máximas: {bcolors.ENDC}{self.max_iterations}")
+        print(f"{bcolors.OKBLUE}Solución Inicial: {bcolors.ENDC}{self.initial_solution.value}")
+        print(f"{bcolors.OKBLUE}Límite de tiempo de ejecución: {bcolors.ENDC}{self.max_time} segundos")
 
         # Opciones para Simulated Annealing
         if (self.metaheuristic == MHType.SA):
             print(f"{bcolors.HEADER}\n\t\tOPCIONES PARA SIMULATED ANNEALING\n {bcolors.ENDC}")        
-            print(f"{bcolors.OKBLUE}Parametro alfa para el enfriamiento: {bcolors.ENDC}{self.alpha}")
+            print(f"{bcolors.OKBLUE}Parámetro alfa para el enfriamiento: {bcolors.ENDC}{self.alpha}")
             print(f"{bcolors.OKBLUE}Temperatura inicial: {bcolors.ENDC}{self.t0}")
-            print(f"{bcolors.OKBLUE}Temperatura minima: {bcolors.ENDC}{self.tmin}")
+            print(f"{bcolors.OKBLUE}Temperatura mínima: {bcolors.ENDC}{self.tmin}")
             print(f"{bcolors.OKBLUE}Tipo de enfriamiento: {bcolors.ENDC}{self.cooling.value}")
         elif (self.metaheuristic == MHType.GA): # Opciones para Algoritmo Genetico
-            print(f"{bcolors.HEADER}\n\t\tOPCIONES PARA ALGORITMO GENETICO\n {bcolors.ENDC}")        
-            print(f"{bcolors.OKBLUE}Cantidad de individuos de la poblacion: {bcolors.ENDC}{self.pop_size}")
+            print(f"{bcolors.HEADER}\n\t\tOPCIONES PARA ALGORITMO GENÉTICO\n {bcolors.ENDC}")        
+            print(f"{bcolors.OKBLUE}Cantidad de individuos de la población: {bcolors.ENDC}{self.pop_size}")
             print(f"{bcolors.OKBLUE}Cantidad de hijos: {bcolors.ENDC}{self.offspring_size}")
-            print(f"{bcolors.OKBLUE}Seleccion de padres: {bcolors.ENDC}{self.pselection_type.value}")
+            print(f"{bcolors.OKBLUE}Selección de padres: {bcolors.ENDC}{self.pselection_type.value}")
             print(f"{bcolors.OKBLUE}Tipo de cruzamiento: {bcolors.ENDC}{self.crossover_type.value}")
-            print(f"{bcolors.OKBLUE}Tipo de mutacion: {bcolors.ENDC}{self.mutation_type.value}")
-            print(f"{bcolors.OKBLUE}Probabilidad de mutacion: {bcolors.ENDC}{self.mutation_prob}")
-            print(f"{bcolors.OKBLUE}Estrategia de seleccion para las nuevas poblaciones: {bcolors.ENDC}{self.selection_strategy.value}")
-            print(f"{bcolors.OKBLUE}Tipo de seleccion de la nueva poblacion: {bcolors.ENDC}{self.gselection_type.value}")
+            print(f"{bcolors.OKBLUE}Tipo de mutación: {bcolors.ENDC}{self.mutation_type.value}")
+            print(f"{bcolors.OKBLUE}Probabilidad de mutación: {bcolors.ENDC}{self.mutation_prob}")
+            print(f"{bcolors.OKBLUE}Estrategia de selección para las nuevas poblaciones: {bcolors.ENDC}{self.selection_strategy.value}")
+            print(f"{bcolors.OKBLUE}Tipo de selección de la nueva población: {bcolors.ENDC}{self.gselection_type.value}")
         elif (self.metaheuristic == MHType.LS or self.metaheuristic == MHType.ILS):
             print(f"{bcolors.HEADER}\n\t\tOPCIONES PARA LOCAL SEARCH E ITERATED LOCAL SEARCH\n {bcolors.ENDC}")        
-            print(f"{bcolors.OKBLUE}Tipo de movimiento para busqueda: {bcolors.ENDC}{self.move.value}")
+            print(f"{bcolors.OKBLUE}Tipo de movimiento para búsqueda: {bcolors.ENDC}{self.move.value}")
             print(f"{bcolors.OKBLUE}Best Improvement: {bcolors.ENDC}{self.bestImprovement}")
-            print(f"{bcolors.OKBLUE}Tipo de perturbacion para busqueda ILS: {bcolors.ENDC}{self.perturbation.value}")
-            print(f"{bcolors.OKBLUE}Numero de perturbaciones a aplicar para busqueda ILS: {bcolors.ENDC}{self.nPerturbations}")
+            print(f"{bcolors.OKBLUE}Tipo de perturbación para búsqueda ILS: {bcolors.ENDC}{self.perturbation.value}")
+            print(f"{bcolors.OKBLUE}Número de perturbaciones a aplicar para búsqueda ILS: {bcolors.ENDC}{self.nPerturbations}")
         
-            
                         
         print()
\ No newline at end of file
