@@ -79,7 +79,7 @@ def main(argv=sys.argv) -> None:
     solver.print_best_solution()
     
     end = timer() # tiempo final de ejecucion
-    print(f"{bcolors.BOLD}Tiempo total de ejecucion: {bcolors.ENDC}{bcolors.OKBLUE} {end-start:.3f} segundos{bcolors.ENDC}")
+    print(f"{bcolors.BOLD}Tiempo total de ejecución: {bcolors.ENDC}{bcolors.OKBLUE} {end-start:.3f} segundos{bcolors.ENDC}")
     
     if options.visualize:
         solver.visualize()
